searchTwitter(searchString, n=25, session = getCurlHandle(), lang=NULL, since=NULL, ...)
Rtweets(n=25, session = getCurlHandle(), lang=NULL, since=NULL, ...)initSessionNULL, restricts tweets to the given language, given by an ISO 639-1 codeNULL, restricts tweets to those since the given date. Date is to be formatted as YYYY-MM-DDgetURLn
argument. The Rtweets function is a wrapper around searchTwitter
which hardcodes in a search for #rstats}.
A premade session will almost never be necessary.
status objectsstatus