Learn R Programming

twitteR (version 0.1.3)

searchTwitter: Search twitter

Description

This function will issue a search of Twitter based on a supplied search string.

Usage

searchTwitter(searchString, session = getCurlHandle(), num=25)

Arguments

searchString
Search query to issue to twitter
session
A session object from initSession
num
The number of tweets to return

Details

A premade session is typically not going to be necessary, this command can be called without any parameters. However, if a user has access to a protected user's timeline, they will not see any #rstat} activity without using a session object. A list of status objects [object Object] status searchTwitter("#rstats", num=100) interface